@@ -26,9 +26,9 @@ TEMPLATE_DIRS = (
     os.path.join(TEST_DIR, 'templates'),
 )
 
-TEMPLATE_CONTEXT_PROCESSORS = global_settings.TEMPLATE_CONTEXT_PROCESSORS + (
+TEMPLATE_CONTEXT_PROCESSORS = global_settings.TEMPLATE_CONTEXT_PROCESSORS + [
     'openstack_dashboard.context_processors.openstack',
-)
+]
 
 INSTALLED_APPS = (
     'django.contrib.contenttypes',
@@ -128,4 +128,5 @@ NOSE_ARGS = ['--nocapture',
              '--nologcapture',
              '--cover-package=monitoring',
              '--cover-inclusive',
+             '--with-xunit',
              '--all-modules']
